==> gcompris-qt-0.50.tar.xz: gcompris-qt-0.50/src/activities/louis-braille/louis_braille_data.js <==
/* GCompris - louis_braille_data.js
 *
 * Copyright (C) 2014 Arkit Vora <arkitvora123@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

var baseUrl = "qrc:/gcompris/src/activities/louis-braille/resource/"

var dataset = [
            {
                 "text": qsTr("Born on January 4th 1809 in Coupvary near Paris in France."),
                 "year": "1809",
                 "img": baseUrl + "louis.png"
             },
             {
                 "text": qsTr("Louis Braille injured his right eye with a stitching awl from his father's workshop."),
                 "year": "1812",
                 "img": baseUrl + "workshop.jpg"
             },
             {
                 "text": qsTr("At the age of three, Louis became blind due to a severe infection that spread to his left eye."),
                 "year": "1812",
                 "img": baseUrl + "fireplace.jpg"
             },
             {
                 "text": qsTr("At the age of 10, he was sent to Paris to study at the Royal Institute for Blind Youth."),
                 "year": "1819",
                 "img": baseUrl + "rnib.jpg"
             },
             {
                 "text": qsTr("He impressed his classmates and began to play the piano and the organ."),
                 "year": "1820",
                 "img": baseUrl + "piano.svg"
             },
             {
                 "text": qsTr("Charles Barbier, a French soldier, visited his school and shared his invention of night writing, a code of 12 raised dots to share information on battlefields."),
                 "year": "1821",
                 "img": baseUrl + "night_printing.jpg"
             },
             {
                 "text": qsTr("Louis trimmed Barbier's 12 dots into 6 and invented the Braille system."),
                 "year": "1824",
                 "img": baseUrl + "braille.jpg"
             },
             {
                 "text": qsTr("He became a teacher after graduating and promoted his method while secretly teaching it at the Institute."),
                 "year": "1828",
                 "img": baseUrl + "teach.jpg"
             },
             {
                 "text": qsTr("He revised and extended braille to include mathematics, symbols, punctuations and music notations."),
                 "year": "1837",
                 "img": baseUrl + "chart.png"
             },
             {
                 "text": qsTr("He died of tuberculosis. He is buried in the Pantheon in Paris. A monument is erected to honor him."),
                 "year": "1852",
                 "img": baseUrl + "statue.jpg"
             },
             {
                 "text": qsTr("Braille got accepted as a world wide standard. Louis Braille proved that if you have motivation you can do incredible things."),
                 "year": "After his Death",
                 "img": baseUrl + "braille_ball.jpg"
             }
        ];

==> gcompris-qt-0.80.tar.xz: gcompris-qt-0.80/src/activities/louis-braille/louis_braille_data.js <==
/* GCompris - louis_braille_data.js
 *
 * Copyright (C) 2014 Arkit Vora <arkitvora123@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

var baseUrl = "qrc:/gcompris/src/activities/louis-braille/resource/"

var dataset = [
            {
                 "text": qsTr("Born on January 4th 1809 in Coupvray near Paris in France."),
                 "year": "1809",
                 "img": baseUrl + "louis.png"
             },
             {
                 "text": qsTr("Louis Braille injured his right eye with a stitching awl from his father's workshop."),
                 "year": "1812",
                 "img": baseUrl + "workshop.jpg"
             },
             {
                 "text": qsTr("At the age of three, Louis became blind due to a severe infection that spread to his left eye."),
                 "year": "1812",
                 "img": baseUrl + "fireplace.jpg"
             },
             {
                 "text": qsTr("At the age of 10, he was sent to Paris to study at the Royal Institute for Blind Youth."),
                 "year": "1819",
                 "img": baseUrl + "rnib.jpg"
             },
             {
                 "text": qsTr("He impressed his classmates and began to play the piano and the organ."),
                 "year": "1820",
                 "img": baseUrl + "piano.svg"
             },
             {
                 "text": qsTr("Charles Barbier, a French soldier, visited his school and shared his invention of night writing, a code of 12 raised dots to share information on battlefields."),
                 "year": "1821",
                 "img": baseUrl + "night_printing.jpg"
             },
             {
                 "text": qsTr("Louis trimmed Barbier's 12 dots into 6 and invented the Braille system."),
                 "year": "1824",
                 "img": baseUrl + "braille.jpg"
             },
             {
                 "text": qsTr("He became a teacher after graduating and promoted his method while secretly teaching it at the Institute."),
                 "year": "1828",
                 "img": baseUrl + "teach.jpg"
             },
             {
                 "text": qsTr("He revised and extended braille to include mathematics, symbols, punctuations and music notations."),
                 "year": "1837",
                 "img": baseUrl + "chart.png"
             },
             {
                 "text": qsTr("He died of tuberculosis. He is buried in the Pantheon in Paris. A monument is erected to honor him."),
                 "year": "1852",
                 "img": baseUrl + "statue.jpg"
             },
             {
                 "text": qsTr("Braille got accepted as a world wide standard. Louis Braille proved that if you have motivation you can do incredible things."),
                 "year": "After his Death",
                 "img": baseUrl + "braille_ball.jpg"
             }
        ];
